
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#include <glib-object.h>
#include <gclue-enums.h>

G_BEGIN_DECLS

/* enumerations from "gclue-enums.h" */

GCLUE_ENUMS_H
GType gclue_accuracy_level_get_type (void);
#define GCLUE_TYPE_ACCURACY_LEVEL (gclue_accuracy_level_get_type())

GCLUE_ENUMS_H
GType gclue_client_proxy_create_flags_get_type (void);
#define GCLUE_TYPE_CLIENT_PROXY_CREATE_FLAGS (gclue_client_proxy_create_flags_get_type())

G_END_DECLS

/* Generated data ends here */

